==> up2b-0.2.3-py3-none-any.whl: up2b/up2b_lib/up2b_api/sm.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author: thepoy
# @Email: thepoy@aliyun.com
# @File Name: sm.py
# @Created: 2021-02-13 09:04:07
# @Modified:  2022-03-09 11:01:14

import requests

from typing import List, Optional, Dict, Any

from up2b.up2b_lib.up2b_api import Base, ImageBedMixin, CONF_FILE
from up2b.up2b_lib.utils import Login, check_image_exists
from up2b.up2b_lib import errors
from up2b.up2b_lib.constants import SM_MS


class SM(Base, ImageBedMixin):
    def __init__(
        self,
        auto_compress: bool = False,
        add_watermark: bool = False,
        conf_file: str = CONF_FILE,
    ):
        self.image_bed_code = SM_MS
        super().__init__(auto_compress, add_watermark, conf_file)

        self.base_url = "https://sm.ms/api/v2/"
        self.max_size = 5 * 1024 * 1024

        if self.auth_info:
            self.token: str = self.auth_info["token"]

            self.headers = {
                "Content-Type": "multipart/form-data",
                "Authorization": self.token,
            }

    def login(self, username: str, password: str):
        token = self._get_api_token(username, password)
        self._save_auth_info(
            {"token": token, "username": username, "password": password}
        )

    def _auto_login(self):
        if not self.auth_info:
            raise ValueError("auth info is not found")
        username = self.auth_info["username"]
        password = self.auth_info["password"]
        self.login(username, password)
        self.auth_info = self._read_auth_info()

    def _get_api_token(self, username: str, password: str) -> str:
        url = self._url("token")
        data = {"username": username, "password": password}
        resp = requests.post(url, data=data).json()
        return resp["data"]["token"]

    def _get_user_profile(self) -> Optional[Dict[str, str]]:
        url = self._url("profile")
        resp = requests.post(url, headers=self.headers).json()
        if resp["success"]:
            return resp["data"]
        else:
            if self._login_expired(resp):
                self._auto_login()
                self.token = self.auth_info["token"]  # type: ignore

    @Login
    def upload_image(self, image_path: str):
        image_path = self._compress_image(image_path)
        image_path = self._add_watermark(image_path)
        # sm.ms不管出不出错，返回的状态码都是200
        url = self._url("upload")
        headers = {"Authorization": self.token}
        files = {"smfile": open(image_path, "rb")}
        resp = requests.post(url, headers=headers, files=files).json()
        if resp["success"]:
            return resp["data"]["url"]
        else:
            if resp["code"] == "image_repeated":
                # 如果图片重复，会返回重复的图片的链接，所以此处不报错
                return resp["images"]
            elif self._login_expired(resp):
                self._auto_login()
                self.token = self.auth_info["token"]  # type: ignore
            else:
                raise errors.UploadFailed(resp["message"])

    @Login
    def upload_images(self, images_path: List[str]) -> List[str]:
        if len(images_path) > 10:
            raise errors.OverSizeError(
                "You can only upload up to 10 pictures, but you uploaded %d pictures."
                % len(images_path)
            )

        check_image_exists(images_path)

        self._check_images_valid(images_path)

        images_url = []
        for img in images_path:
            try:
                result = self.upload_image(img)
            except errors.UploadFailed as e:
                result = {"image_path": img, "status_code": 400, "error": f"{e}"}

            images_url.append(result)

        for i in images_url:
            print(i)

        self._clear_cache()

        return images_url

    @Login
    def history(self) -> Dict[str, Any]:
        """
        Temporary History - IP Based Temporary Upload History
        """
        url = self._url("history")
        resp = requests.get(url, headers=self.headers)
        return resp.json()

    @Login
    def clear(self) -> Dict[str, Any]:
        """
        Clear Temporary History - Clear IP Based Temporary Upload History
        """
        url = self._url("clear")
        resp = requests.get(url, headers=self.headers)
        return resp.json()

    @Login
    def upload_history(self) -> dict:
        url = self._url("upload_history")
        resp = requests.get(url, headers=self.headers)
        return resp.json()

    @Login
    def get_all_images(self) -> List[Dict[str, str]]:
        images = []
        for file in self.upload_history()["data"]:
            images.append(
                {
                    "url": file["url"],
                    "delete_url": file["delete"],
                    "width": file["width"],
                    "height": file["height"],
                }
            )

        return images

    @Login
    def delete_image(self, delete_url: str) -> bool:
        resp = requests.get(delete_url, headers=self.headers)
        # TODO: sm.ms 删除图片后本应返回json，但实际返回的是html。而且删除链接不需要认证，任何人get都能删除图片
        return resp.status_code == 200

    @Login
    def delete_images(self, urls: List[str]) -> dict:
        result = {}
        for url in urls:
            r = self.delete_image(url)
            # if not r["success"]:
            #     result[hash] = {"message": r["message"], "code": r["code"]}
            result[url] = r
        return result

    @Login
    def get_all_images_in_image_bed(self) -> List[str]:  # type: ignore
        pass

    def _url(self, path: str) -> str:
        return self.base_url + path

    def _login_expired(self, resp: dict):
        return resp["message"] == "Get user profile failed, invalid Authorization."

    def __repr__(self):
        return "sm.ms"

    def __str__(self):
        return self.__repr__()

==> up2b-0.2.4-py3-none-any.whl: up2b/up2b_lib/up2b_api/sm.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author: thepoy
# @Email: thepoy@aliyun.com
# @File Name: sm.py
# @Created: 2021-02-13 09:04:07
# @Modified:  2022-03-10 11:36:28

import requests

from typing import List, Optional, Dict, Any

from up2b.up2b_lib.up2b_api import Base, ImageBedMixin, CONF_FILE
from up2b.up2b_lib import errors
from up2b.up2b_lib.constants import SM_MS
from up2b.up2b_lib.utils import Login, check_image_exists, child_logger

logger = child_logger(__name__)


class SM(Base, ImageBedMixin):
    def __init__(
        self,
        auto_compress: bool = False,
        add_watermark: bool = False,
        conf_file: str = CONF_FILE,
    ):
        self.image_bed_code = SM_MS
        super().__init__(auto_compress, add_watermark, conf_file)

        self.base_url = "https://sm.ms/api/v2/"
        self.max_size = 5 * 1024 * 1024

        if self.auth_info:
            self.token: str = self.auth_info["token"]

            self.headers = {
                "Content-Type": "multipart/form-data",
                "Authorization": self.token,
            }

    def login(self, username: str, password: str):
        token = self._get_api_token(username, password)
        self._save_auth_info(
            {"token": token, "username": username, "password": password}
        )

    def _auto_login(self):
        if not self.auth_info:
            raise ValueError("auth info is not found")
        username = self.auth_info["username"]
        password = self.auth_info["password"]
        self.login(username, password)
        self.auth_info = self._read_auth_info()

    def _get_api_token(self, username: str, password: str) -> str:
        url = self._url("token")
        data = {"username": username, "password": password}
        resp = requests.post(url, data=data).json()
        return resp["data"]["token"]

    def _get_user_profile(self) -> Optional[Dict[str, str]]:
        url = self._url("profile")
        resp = requests.post(url, headers=self.headers).json()
        if resp["success"]:
            return resp["data"]
        else:
            if self._login_expired(resp):
                self._auto_login()
                self.token = self.auth_info["token"]  # type: ignore

    @Login
    def upload_image(self, image_path: str):
        logger.debug("uploading: %s", image_path)

        image_path = self._compress_image(image_path)
        image_path = self._add_watermark(image_path)
        # sm.ms不管出不出错，返回的状态码都是200
        url = self._url("upload")
        headers = {"Authorization": self.token}
        files = {"smfile": open(image_path, "rb")}
        resp = requests.post(url, headers=headers, files=files).json()
        if resp["success"]:
            uploaded_url = resp["data"]["url"]
            logger.debug("uploaded: %s => %s", image_path, uploaded_url)
            return uploaded_url
        else:
            if resp["code"] == "image_repeated":
                # 如果图片重复，会返回重复的图片的链接，所以此处不报错
                logger.info("repeated image: %s", resp["images"])
                return resp["images"]
            elif self._login_expired(resp):
                self._auto_login()
                self.token = self.auth_info["token"]  # type: ignore
            else:
                error = resp["message"]
                logger.error("upload failed: img=%s, error=%s", image_path, error)
                raise errors.UploadFailed(error)

    @Login
    def upload_images(self, images_path: List[str]) -> List[str]:
        if len(images_path) > 10:
            raise errors.OverSizeError(
                "You can only upload up to 10 pictures, but you uploaded %d pictures."
                % len(images_path)
            )

        check_image_exists(images_path)

        self._check_images_valid(images_path)

        images_url = []
        for img in images_path:
            try:
                result = self.upload_image(img)
            except errors.UploadFailed as e:
                result = {"image_path": img, "status_code": 400, "error": f"{e}"}

            images_url.append(result)

        for i in images_url:
            print(i)

        self._clear_cache()

        return images_url

    @Login
    def history(self) -> Dict[str, Any]:
        """
        Temporary History - IP Based Temporary Upload History
        """
        url = self._url("history")
        resp = requests.get(url, headers=self.headers)
        return resp.json()

    @Login
    def clear(self) -> Dict[str, Any]:
        """
        Clear Temporary History - Clear IP Based Temporary Upload History
        """
        url = self._url("clear")
        resp = requests.get(url, headers=self.headers)
        return resp.json()

    @Login
    def upload_history(self) -> dict:
        url = self._url("upload_history")
        resp = requests.get(url, headers=self.headers)
        return resp.json()

    @Login
    def get_all_images(self) -> List[Dict[str, str]]:
        images = []
        for file in self.upload_history()["data"]:
            images.append(
                {
                    "url": file["url"],
                    "delete_url": file["delete"],
                    "width": file["width"],
                    "height": file["height"],
                }
            )

        return images

    @Login
    def delete_image(self, delete_url: str) -> bool:
        resp = requests.get(delete_url, headers=self.headers)
        # TODO: sm.ms 删除图片后本应返回json，但实际返回的是html。而且删除链接不需要认证，任何人get都能删除图片
        return resp.status_code == 200

    @Login
    def delete_images(self, urls: List[str]) -> dict:
        result = {}
        for url in urls:
            r = self.delete_image(url)
            # if not r["success"]:
            #     result[hash] = {"message": r["message"], "code": r["code"]}
            result[url] = r
        return result

    @Login
    def get_all_images_in_image_bed(self) -> List[str]:  # type: ignore
        pass

    def _url(self, path: str) -> str:
        return self.base_url + path

    def _login_expired(self, resp: dict):
        return resp["message"] == "Get user profile failed, invalid Authorization."

    def __repr__(self):
        return "sm.ms"
